
=================
Available Schemas
=================

.. This file is autogenerated by the build-schemas-list.py script. Do not edit manually.

These are the topics that you can expect to see on Fedora's message bus,
sorted by the python package that contains their schema.
Install the corresponding python package if you want to make use of the schema
and access additional information on the message you're receiving.

In the Fedora Infrastructure, some of those topics will be prefixed by
``org.fedoraproject.stg.`` in staging and ``org.fedoraproject.prod.`` in production.


anitya
======

You can view the history of `all anitya messages <https://apps.fedoraproject.org/datagrepper/raw?category=anitya>`__ in datagrepper.

* ``org.release-monitoring.prod.anitya.distro.add``: Message sent by Anitya to the "anitya.distro.add" topic when a new distribution is added. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.distro.add>`__)
* ``org.release-monitoring.prod.anitya.distro.edit``: Message sent by Anitya when a distribution is edited. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.distro.edit>`__)
* ``org.release-monitoring.prod.anitya.distro.remove``: Message sent by Anitya when a distribution is removed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.distro.remove>`__)
* ``org.release-monitoring.prod.anitya.project.add``: The message sent when a new project is created in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.add>`__)
* ``org.release-monitoring.prod.anitya.project.edit``: The message sent when a project is edited in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.edit>`__)
* ``org.release-monitoring.prod.anitya.project.flag``: Sent when a new flag is created for a project. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.flag>`__)
* ``org.release-monitoring.prod.anitya.project.flag.set``: Sent when a flag is closed for a project. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.flag.set>`__)
* ``org.release-monitoring.prod.anitya.project.map.new``: Sent when new distribution mapping is created in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.map.new>`__)
* ``org.release-monitoring.prod.anitya.project.map.remove``: Sent when distribution mapping is deleted in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.map.remove>`__)
* ``org.release-monitoring.prod.anitya.project.map.update``: Sent when distribution mapping is edited in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.map.update>`__)
* ``org.release-monitoring.prod.anitya.project.remove``: The message sent when a project is deleted in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.remove>`__)
* ``org.release-monitoring.prod.anitya.project.version.remove``: Sent when version is deleted in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.version.remove>`__)
* ``org.release-monitoring.prod.anitya.project.version.remove.v2``: Sent when version is deleted in Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.version.remove.v2>`__)
* ``org.release-monitoring.prod.anitya.project.version.update``: Sent when new version is discovered by Anitya. This message will be deprecated in future. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.version.update>`__)
* ``org.release-monitoring.prod.anitya.project.version.update.v2``: Sent when new versions are discovered by Anitya. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.release-monitoring.prod.anitya.project.version.update.v2>`__)


bodhi
=====

You can view the history of `all bodhi messages <https://apps.fedoraproject.org/datagrepper/raw?category=bodhi>`__ in datagrepper.

* ``bodhi.buildroot_override.tag``: Sent when a buildroot override is added and tagged into the build root. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.buildroot_override.tag>`__)
* ``bodhi.buildroot_override.untag``: Sent when a buildroot override is untagged from the build root. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.buildroot_override.untag>`__)
* ``bodhi.compose.complete``: Sent when a compose task completes. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.compose.complete>`__)
* ``bodhi.compose.composing``: Sent when the compose task composes. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.compose.composing>`__)
* ``bodhi.compose.start``: Sent when a compose task starts. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.compose.start>`__)
* ``bodhi.compose.sync.done``: Sent when a compose task sync is done. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.compose.sync.done>`__)
* ``bodhi.compose.sync.wait``: Sent when a compose task sync is waiting. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.compose.sync.wait>`__)
* ``bodhi.errata.publish``: Sent when an errata is published. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.errata.publish>`__)
* ``bodhi.repo.done``: Sent when a repo is created and ready to be signed or otherwise processed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.repo.done>`__)
* ``bodhi.update.comment``: Sent when a comment is made on an update. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.comment>`__)
* ``bodhi.update.complete.stable``: Sent when an update is available in the stable repository. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.complete.stable>`__)
* ``bodhi.update.complete.testing``: Sent when an update is available in the testing repository. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.complete.testing>`__)
* ``bodhi.update.edit``: Sent when an update is edited. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.edit>`__)
* ``bodhi.update.edit``: Sent when an update is edited. Newer version. Has 'new_builds' and 'removed_builds' properties. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.edit>`__)
* ``bodhi.update.eject``: Sent when an update is ejected from the push. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.eject>`__)
* ``bodhi.update.karma.threshold.reach``: Sent when an update reaches its karma threshold. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.karma.threshold.reach>`__)
* ``bodhi.update.request.obsolete``: Sent when an update is requested to be obsoleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.request.obsolete>`__)
* ``bodhi.update.request.revoke``: Sent when an update is revoked. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.request.revoke>`__)
* ``bodhi.update.request.stable``: Sent when an update is submitted as a stable candidate. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.request.stable>`__)
* ``bodhi.update.request.testing``: Sent when an update is submitted as a testing candidate. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.request.testing>`__)
* ``bodhi.update.request.unpush``: Sent when an update is requested to be unpushed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.request.unpush>`__)
* ``bodhi.update.requirements_met.stable``: Sent when all the update requirements are met for stable. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.requirements_met.stable>`__)
* ``bodhi.update.status.testing.koji-build-group.build.complete``: Sent when an update is ready to be tested. Original version. Does not have 'update' property or inherit from UpdateMessage. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.status.testing.koji-build-group.build.complete>`__)
* ``bodhi.update.status.testing.koji-build-group.build.complete``: Sent when an update is ready to be tested. Newer version. Has 'update' property, like other update messages. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.status.testing.koji-build-group.build.complete>`__)
* ``bodhi.update.status.testing.koji-build-group.build.complete``: Sent when an update is ready to be tested. Simplified version. Specifically, this message is sent: * When an update is created * When an update is edited and its builds change * When a "re-trigger tests" request is made via the web UI or API These are the points where we expect that automated systems will test the update. Inherits from UpdateMessage and only contains as much extra information (in the 'artifact' dict) as the Fedora CI schedulers actually need. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.bodhi.update.status.testing.koji-build-group.build.complete>`__)


Copr
====

You can view the history of `all Copr messages <https://apps.fedoraproject.org/datagrepper/raw?category=copr>`__ in datagrepper.

* ``copr.build.end``: schema for the old fedmsg-era 'copr.build.end' message (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.copr.build.end>`__)
* ``copr.build.start``: schema for the old fedmsg-era 'copr.build.start' message (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.copr.build.start>`__)
* ``copr.chroot.start``: Schema for the old fedmsg-era 'copr.chroot.start' message, this message duplicated the 'copr.build.start' message, so you should never use this. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.copr.chroot.start>`__)
* ``build.end`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.build.end>`__)
* ``build.start`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.build.start>`__)
* ``chroot.start`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.chroot.start>`__)


fedocal
=======

You can view the history of `all fedocal messages <https://apps.fedoraproject.org/datagrepper/raw?category=fedocal>`__ in datagrepper.

* ``fedocal.calendar.clear``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a calendar is cleared. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.calendar.clear>`__)
* ``fedocal.calendar.delete``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a calendar is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.calendar.delete>`__)
* ``fedocal.calendar.new``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a calendar is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.calendar.new>`__)
* ``fedocal.calendar.update``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a calendar is updated. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.calendar.update>`__)
* ``fedocal.calendar.upload``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when meetings have been uploaded into the calendar. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.calendar.upload>`__)
* ``fedocal.meeting.delete``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a meeting is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.meeting.delete>`__)
* ``fedocal.meeting.new``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a meeting is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.meeting.new>`__)
* ``fedocal.meeting.reminder``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a reminder is sent. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.meeting.reminder>`__)
* ``fedocal.meeting.update``: A sub-class of a Fedora message that defines a message schema for messages published by fedocal when a meeting is updated. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedocal.meeting.update>`__)


elections
=========

You can view the history of `all elections messages <https://apps.fedoraproject.org/datagrepper/raw?category=fedora_elections>`__ in datagrepper.

* ``fedora_elections.candidate.delete``: A sub-class of a Fedora message that defines a message schema for messages published by Elections when a candidate is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedora_elections.candidate.delete>`__)
* ``fedora_elections.candidate.edit``: A sub-class of a Fedora message that defines a message schema for messages published by Elections when a candidate is edited. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedora_elections.candidate.edit>`__)
* ``fedora_elections.candidate.new``: A sub-class of a Fedora message that defines a message schema for messages published by Elections when a new candidate is added. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedora_elections.candidate.new>`__)
* ``fedora_elections.election.edit``: A sub-class of a Fedora message that defines a message schema for messages published by Elections when an election is edited. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedora_elections.election.edit>`__)
* ``fedora_elections.election.new``: A sub-class of a Fedora message that defines a message schema for messages published by Elections when a new election is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fedora_elections.election.new>`__)


Git
===

You can view the history of `all Git messages <https://apps.fedoraproject.org/datagrepper/raw?category=git>`__ in datagrepper.

* ``git.receive``: A sub-class of a Fedora message that defines a message schema for messages published by Fedora Messaging Git Hook when a new commit is received. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.git.receive>`__)


The New Hotness
===============

You can view the history of `all The New Hotness messages <https://apps.fedoraproject.org/datagrepper/raw?category=hotness>`__ in datagrepper.

* ``org.fedoraproject.prod.hotness.update.bug.file``: Message sent by the-new-hotness to "hotness.update.bug.file" topic when bugzilla issue is filled. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.hotness.update.bug.file>`__)
* ``org.fedoraproject.prod.hotness.update.drop``: Message sent by the-new-hotness to "hotness.update.drop" topic when update is dropped. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.hotness.update.drop>`__)


planet
======

You can view the history of `all planet messages <https://apps.fedoraproject.org/datagrepper/raw?category=planet>`__ in datagrepper.

* ``org.fedoraproject.prod.planet.post.new``: The message sent when a new post is published in planet. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.planet.post.new>`__)


ansible
=======

You can view the history of `all ansible messages <https://apps.fedoraproject.org/datagrepper/raw?category=ansible>`__ in datagrepper.

* ``ansible.playbook.complete``: Defines the message that is sent when an Ansible Playbook completes (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.ansible.playbook.complete>`__)
* ``ansible.playbook.start``: Defines the message that is sent when an Ansible Playbook starts (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.ansible.playbook.start>`__)
* ``git.receive``: Defines the message that is sent when an Ansible Playbook starts (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.git.receive>`__)


FMN
===

You can view the history of `all FMN messages <https://apps.fedoraproject.org/datagrepper/raw?category=fmn>`__ in datagrepper.

* ``fmn.rule.update.v1`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fmn.rule.update.v1>`__)
* ``fmn.rule.delete.v1`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fmn.rule.delete.v1>`__)
* ``fmn.rule.update.v1`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fmn.rule.update.v1>`__)


kerneltest
==========

You can view the history of `all kerneltest messages <https://apps.fedoraproject.org/datagrepper/raw?category=kerneltest>`__ in datagrepper.

* ``kerneltest.release.edit``: The message sent when an admin creates a new release (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.kerneltest.release.edit>`__)
* ``kerneltest.release.new``: The message sent when an admin creates a new release (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.kerneltest.release.new>`__)
* ``kerneltest.upload.new``: The message sent when a user uploads a new kerneltest (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.kerneltest.upload.new>`__)


Koji
====

You can view the history of `all Koji messages <https://apps.fedoraproject.org/datagrepper/raw?category=buildsys>`__ in datagrepper.

* ``buildsys.build.state.change``: This message is sent when a build state changes. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.build.state.change>`__)
* ``buildsys.package.list.change``: This message is sent when a package list changes. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.package.list.change>`__)
* ``buildsys.repo.done``: This message is sent when a package repo is done. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.repo.done>`__)
* ``buildsys.repo.init``: This message is sent when a package repo is initialized. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.repo.init>`__)
* ``buildsys.rpm.sign``: This message is sent when a rpm is signed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.rpm.sign>`__)
* ``buildsys.tag``: This message is sent when a package is tagged. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.tag>`__)
* ``buildsys.untag``: This message is sent when a package is untagged. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.untag>`__)
* ``buildsys.task.state.change``: This message is sent when a task state changes. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.buildsys.task.state.change>`__)


Koschei
=======

You can view the history of `all Koschei messages <https://apps.fedoraproject.org/datagrepper/raw?category=koschei>`__ in datagrepper.

* ``koschei.collection.state.change``: Messages published by Koschei when a collection state changes.     For example when collection buildroot becomes unresolvable     (broken) or when it is fixed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.koschei.collection.state.change>`__)
* ``koschei.package.state.change``: Messages published by Koschei when a package state changes.     For example when package starts to fail to build, package     dependencies become unresolved or when package is fixed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.koschei.package.state.change>`__)


Maubot Fedora
=============

You can view the history of `all Maubot Fedora messages <https://apps.fedoraproject.org/datagrepper/raw?category=maubot>`__ in datagrepper.

* ``maubot.cookie.give.v1``: A sub-class of a Fedora message that defines a message schema for messages published by Maubot Fedora when a cookie is given. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.maubot.cookie.give.v1>`__)


mdapi
=====

You can view the history of `all mdapi messages <https://apps.fedoraproject.org/datagrepper/raw?category=mdapi>`__ in datagrepper.

* ``mdapi.repo.update``: A sub-class of a Fedora message that defines a message schema for messages published by mdapi when a repo's info is updated. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.mdapi.repo.update>`__)


Wiki
====

You can view the history of `all Wiki messages <https://apps.fedoraproject.org/datagrepper/raw?category=wiki>`__ in datagrepper.

* ``wiki.article.edit``: A sub-class of a Fedora message that defines a message schema for messages published by Mediawiki when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.wiki.article.edit>`__)


meetbot
=======

You can view the history of `all meetbot messages <https://apps.fedoraproject.org/datagrepper/raw?category=meetbot>`__ in datagrepper.

* ``meetbot.meeting.complete`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.meetbot.meeting.complete>`__)
* ``meetbot.meeting.start`` (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.meetbot.meeting.start>`__)


FAS
===

You can view the history of `all FAS messages <https://apps.fedoraproject.org/datagrepper/raw?category=fas>`__ in datagrepper.

* ``fas.group.member.sponsor``: The message sent when a user is added to a group by a sponsor (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fas.group.member.sponsor>`__)
* ``fas.user.create``: The message sent when a user is created (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fas.user.create>`__)
* ``fas.user.update``: The message sent when a user is updated (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.fas.user.update>`__)


nuancier
========

You can view the history of `all nuancier messages <https://apps.fedoraproject.org/datagrepper/raw?category=nuancier>`__ in datagrepper.

* ``nuancier.new``: A sub-class of a Fedora message that defines a message schema for messages published by nuancier when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.nuancier.new>`__)


Pagure
======

You can view the history of `all Pagure messages <https://apps.fedoraproject.org/datagrepper/raw?category=pagure>`__ in datagrepper.

* ``pagure.Test.notification``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.Test.notification>`__)
* ``pagure.commit.flag.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.commit.flag.added>`__)
* ``pagure.commit.flag.updated``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.commit.flag.updated>`__)
* ``pagure.git.branch.creation``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.git.branch.creation>`__)
* ``pagure.git.branch.deletion``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.git.branch.deletion>`__)
* ``pagure.git.receive``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.git.receive>`__)
* ``pagure.git.tag.creation``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.git.tag.creation>`__)
* ``pagure.git.tag.deletion``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.git.tag.deletion>`__)
* ``pagure.group.edit``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.group.edit>`__)
* ``pagure.issue.assigned.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is assigned. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.assigned.added>`__)
* ``pagure.issue.assigned.reset``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is un-assigned. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.assigned.reset>`__)
* ``pagure.issue.comment.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a comment is added to an issue. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.comment.added>`__)
* ``pagure.issue.dependency.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a dependency is added to an issue. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.dependency.added>`__)
* ``pagure.issue.dependency.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.dependency.removed>`__)
* ``pagure.issue.drop``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.drop>`__)
* ``pagure.issue.edit``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is updated. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.edit>`__)
* ``pagure.issue.new``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.new>`__)
* ``pagure.issue.tag.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.tag.added>`__)
* ``pagure.issue.tag.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an issue is deleted. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.issue.tag.removed>`__)
* ``pagure.project.deleted``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.deleted>`__)
* ``pagure.project.edit``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.edit>`__)
* ``pagure.project.forked``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.forked>`__)
* ``pagure.project.group.access.updated``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.group.access.updated>`__)
* ``pagure.project.group.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.group.added>`__)
* ``pagure.project.group.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.group.removed>`__)
* ``pagure.project.new``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.new>`__)
* ``pagure.project.tag.edited``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.tag.edited>`__)
* ``pagure.project.tag.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.tag.removed>`__)
* ``pagure.project.user.access.updated``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.user.access.updated>`__)
* ``pagure.project.user.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.user.added>`__)
* ``pagure.project.user.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a new thing is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.project.user.removed>`__)
* ``pagure.pull-request.assigned.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a pull request is assigned. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.assigned.added>`__)
* ``pagure.pull-request.assigned.reset``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a pull request is un-assigned. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.assigned.reset>`__)
* ``pagure.pull-request.closed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a pull request is closed. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.closed>`__)
* ``pagure.pull-request.comment.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a comment is added to a PR. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.comment.added>`__)
* ``pagure.pull-request.comment.edited``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a comment is edited on a PR. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.comment.edited>`__)
* ``pagure.pull-request.flag.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a flag is added on a PR. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.flag.added>`__)
* ``pagure.pull-request.flag.updated``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a flag is updated on a PR (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.flag.updated>`__)
* ``pagure.pull-request.initial_comment.edited``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when an initial PR comment is edited. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.initial_comment.edited>`__)
* ``pagure.pull-request.new``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a pull request is created. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.new>`__)
* ``pagure.pull-request.rebased``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a PR is rebased. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.rebased>`__)
* ``pagure.pull-request.reopened``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a PR is reopened. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.reopened>`__)
* ``pagure.pull-request.tag.added``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a tag is added on a PR. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.tag.added>`__)
* ``pagure.pull-request.tag.removed``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a tag is removed on a PR. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.tag.removed>`__)
* ``pagure.pull-request.updated``: A sub-class of a Fedora message that defines a message schema for messages published by pagure when a PR is updated. (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.pagure.pull-request.updated>`__)


tahrir
======

You can view the history of `all tahrir messages <https://apps.fedoraproject.org/datagrepper/raw?category=badges>`__ in datagrepper.

* ``badges.badge.award``: The message sent when a badge is awarded (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.badges.badge.award>`__)
* ``badges.person.login.first``: The message sent when a user logs into tahrir for the first time (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.badges.person.login.first>`__)
* ``badges.person.rank.advance``: The message sent when a user's rank changes (`history <https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod.badges.person.rank.advance>`__)
